@@ -1,8 +1,10 @@
 import argparse
+import asyncio
 
 from functools import partial
 
-from i3ipc import Connection, Event
+from i3ipc import Event
+from i3ipc.aio import Connection
 
 
 def is_floating(container) -> bool:
@@ -15,18 +17,20 @@ def is_floating(container) -> bool:
         return container.type == "floating_con"
 
 
-def set_splitting(i3, _, width: int):
-    focused = i3.get_tree().find_focused()
+async def set_splitting(i3, _, width: int) -> None:
+    focused = (await i3.get_tree()).find_focused()
+    if focused is None:
+        return
     workspace = focused.workspace()
     number_of_tiled_windows = len([leaf for leaf in workspace.leaves() if not is_floating(leaf)])
     if number_of_tiled_windows == 1:
-        focused.command("splith")
+        await focused.command("splith")
     elif number_of_tiled_windows == 2:
-        focused.command("splitv")
-        focused.command(f"resize set width {width} ppt")
+        await focused.command("splitv")
+        await focused.command(f"resize set width {width} ppt")
 
 
-def main():
+async def amain():
     parser = argparse.ArgumentParser(description="Stack layout for i3/sway wm.")
     parser.add_argument(
         "width",
@@ -37,7 +41,11 @@ def main():
     )
     args = parser.parse_args()
     width = min(max(args.width, 0), 100)
-    i3 = Connection()
-    i3.on(Event.WINDOW_NEW, partial(set_splitting, width=width))
-    i3.on(Event.WINDOW_CLOSE, partial(set_splitting, width=width))
-    i3.main()
+    i3 = await Connection(auto_reconnect=True).connect()
+    i3.on(Event.WINDOW_NEW, partial(set_splitting, width=width)) # type: ignore
+    i3.on(Event.WINDOW_CLOSE, partial(set_splitting, width=width)) # type: ignore
+    await i3.main()
+
+
+def main():
+    asyncio.run(amain())
